#!/usr/bin/env bash

file_env() {
	# 3wc: Load $VAR_FILE into $VAR - useful for secrets. See
	# 	https://medium.com/@adrian.gheorghe.dev/using-docker-secrets-in-your-environment-variables-7a0609659aab
	local var="$1"
	local fileVar="${var}_FILE"
	local def="${2:-}"

	if [ "${!var:-}" ] && [ "${!fileVar:-}" ]; then
		echo >&2 "error: both $var and $fileVar are set (but are exclusive)"
		exit 1
	fi
	local val="$def"
	if [ "${!var:-}" ]; then
		val="${!var}"
	elif [ "${!fileVar:-}" ]; then
		val="$(< "${!fileVar}")"
	fi
	export "$var"="$val"
	unset "$fileVar"
}

load_vars() {
	file_env "PENPOT_DATABASE_PASSWORD"
  file_env "PENPOT_SECRET_KEY"
	file_env "PENPOT_SMTP_PASSWORD"
	file_env "PENPOT_LDAP_BIND_PASSWORD"
	file_env "PENPOT_GOOGLE_CLIENT_SECRET"
	file_env "PENPOT_GITHUB_CLIENT_SECRET"
	file_env "PENPOT_GITLAB_CLIENT_SECRET"
	file_env "PENPOT_OIDC_CLIENT_SECRET"
}

main() {
	set -eu

	load_vars
}

main

# 3wc: upstream ENTRYPOINT
# https://github.com/penpot/penpot/blob/develop/docker/images/Dockerfile.backend
./run.sh
